<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>系统监视器</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>系统监视器是一个对硬件负载、程序运行和系统服务，进行监测查看和管理操作的系统工具。</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>隐藏详情</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation>总体利用率</translation>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation>个体利用率</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>读取</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>写入</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60秒</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1天%2小时%3分钟</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>总利用率</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>当前频率</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>频率</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>制造商</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>插槽</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>逻辑处理器</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>虚拟化</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>L1缓存（指令）</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>L1缓存（数据）</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>L2缓存</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>L3缓存</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>平均负载</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>文件描述符数</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>进程数</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>线程数</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>主机名</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>类型</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>运行时间</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60秒</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>无搜索结果</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>详细信息</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>详细信息</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>已启动</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>重载中</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>未启动</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>已失败</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>启动中</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>停止中</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>占位</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>未找到</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>无效设置</translation>
    </message>
    <message>
        <source>error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>已合并</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>已屏蔽</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>已加载</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手动</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>已启用</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>已禁用</translation>
    </message>
    <message>
        <source>static</source>
        <translation>静态</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>瞬态</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>间接</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>运行时启用</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>已屏蔽</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>已生成</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>dead</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>预启动</translation>
    </message>
    <message>
        <source>start</source>
        <translation>启动中</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>start-post</translation>
    </message>
    <message>
        <source>running</source>
        <translation>正在运行</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>已退出</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>重载中</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>已停止</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>stop-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>stop-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>stop-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>stop-post</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>final-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>final-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>已失败</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>自动重启</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>已使用</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>可用</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>共享内存</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>高速缓存</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>数据缓存</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>交换缓存区</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>活跃的缓冲文件</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>不活跃的缓冲文件</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>脏页</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>映射大小</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>交换空间大小</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>可用交换空间</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>内核数据结构缓存</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>型号</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>读取速度</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>写入速度</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>容量</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>读扇区次数</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>每秒读操作次数</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>每秒读扇区次数</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>每秒合并读操作次数</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>写扇区次数</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>写完成次数</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>合并写完成次数</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>每秒写操作次数</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>每秒写扇区次数</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>每秒合并写操作次数</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>确 定</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>系统</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>显示快捷键</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>结束进程会有丢失数据的风险。
您确定要结束选中的进程吗？</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>结束进程</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>强制结束进程会有丢失数据的风险。
您确定要结束选中的进程吗？</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>强制结束应用会有丢失数据的风险。
您确定要结束选中的应用吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>强制结束</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>结束进程</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>容量大小</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>IP地址：</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>子网掩码：</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>广播：</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>掩码长度：</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>域：</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>连接类型</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>服务器别号</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>信号质量</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>信号强度</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>底噪</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>速率</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>接收包数量</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>总计接收</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>接收（错误包）</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>接收（丢弃包）</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>接收FIFO</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>分组帧错误</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>发送包数量</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>总计发送</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>发送（错误包）</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>发送FIFO</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>载波损耗</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>发送（丢弃包）</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>命令行</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>启动时间</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>进程名</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>点击您想结束的应用程序</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>内存</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>接收</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>处理器</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>磁盘读取</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>磁盘写入</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>内存</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>交换空间</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>未启用</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>正在接收</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>正在发送</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>总计接收</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>总计发送</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>发送</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>磁盘</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>非常高</translation>
    </message>
    <message>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>普通</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>非常低</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>自定义</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>无效</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>进程号: %1, Error: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>改变进程优先级失败</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>应用程序</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>我的进程</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>所有进程</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation>正在加载</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>暂停进程失败</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>恢复进程失败</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>强制结束进程失败</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>未知错误</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>发送信号到进程失败 </translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>结束进程失败</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>（正在运行%1个应用程序和%2个系统进程）</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>无响应</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>托盘</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>查看命令所在位置</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>属性</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>结束进程</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>继续进程</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>强制结束进程</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>改变优先级</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>暂停进程</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>自定义优先级</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>更 改</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>处理器</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>内存</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>磁盘写入</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>磁盘读取</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>上传</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>进程号</translation>
    </message>
    <message>
        <source>User</source>
        <translation>用户</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>优先级</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>共享内存</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>虚拟内存</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>不支持</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>系统防护</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>当数值高于以下阈值时自动报警</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>消息通知</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>CPU占用 (%)</translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>内存占用 (%)</translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>预警间隔 (分钟)</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>服务的启动方式设置失败</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>错误：由于子进程崩溃，服务的启动方式设置失败</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>服务实例名</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>确 定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>刷新</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>启动</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>重新启动</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手动</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>设置启动方式</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>内存加载</translation>
    </message>
    <message>
        <source>Start State</source>
        <translation>启动状态</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>运行状态</translation>
    </message>
    <message>
        <source>Start Tactic</source>
        <translation>启用策略</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>进程号</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>启动方式</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>（阈值可修改）</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>数值范围：%1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>强制结束应用程序</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>舒展</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>紧凑</translation>
    </message>
    <message>
        <source>View</source>
        <translation>视图</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>程序进程</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>系统服务</translation>
    </message>
</context>
</TS>
